/*   	
	procedure:	FillRecoveryAccountProviders.prc
	written by:    	Craig Deane
     	date written:  	June 2021
     	database:      	welcoll
     	function:      	This fills the RecoveryAccountProviders table with debtor data
     	modified by:  	
     	changes:	
*/

use welcoll
go

IF EXISTS(SELECT 1
          FROM   INFORMATION_SCHEMA.ROUTINES
          WHERE  ROUTINE_NAME = 'FillRecoveryAccountProviders'
                 AND SPECIFIC_SCHEMA = 'dbo')
  BEGIN
      DROP PROCEDURE dbo.FillRecoveryAccountProviders
  END
go

create procedure dbo.FillRecoveryAccountProviders
as

delete RecoveryAccountProviders

insert RecoveryAccountProviders
select 	"Legacy Account Number Identifier" = LegacyAccountNumberIdentifier,

	"Organization ID" = 'X' + Convert(char(8), debtor.debtor_id),

	"Organization Name" = debtor1_name_first + ' ' + debtor1_name_mid_init + ' ' + debtor1_name_last,

	"Tax Type Code"	= '',

	"Tax ID Type" = 'SN',

	"Tax ID" = debtor1_ssn,

	"Physical Address - Line 1 Address" = '',

	"Physical  Address - Line 2 Address" = '',

	"Physical  Address - City Name" = '',

	"Physical  Address- State Code" = '',

	"Physical  Address - Zip Code" = '',

	"Mailing Address- Line 1 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line1 from AddressFunction(debtor1_street_address)) Else
						Case When IsNull(debtor1_private_mailbox, '') <> '' Then debtor1_private_mailbox Else
							Case When IsNull(debtor1_care_of_address, '') <> '' Then debtor1_care_of_address End 
						End 
					    End,

	"Mailing Address- Line 2 Address" = Case When IsNull(debtor1_street_address, '') <> '' Then (select address_line2 from AddressFunction(debtor1_street_address)) End,

	"Mailing Address - City Name" = debtor1_city,

	"Mailing Address- State Code" = debtor1_state,

	"Mailing Address - Zip Code" =  debtor1_zip,

	"Phone Number - Area Code" = substring(debtor1_phone, 1, 3),

	"Phone Number" = substring(debtor1_phone, 4, 7),

	"Phone Extension Number" = ''

from debt
INNER JOIN debtor ON debt.debtor_id = debtor.debtor_id
INNER JOIN DebtList ON debt.debt_number = DebtList.debt_number
JOIN LegacyAccountNumberIdentifierFunction() ON debt.debt_number = LegacyAccountNumberIdentifierFunction.debt_number
where type_code in ('FOS', 'IHS', 'AAP') and
	IsNull(provider_number, '') = '' and
	IsNull(cin1, '') = '' and
	IsNull(cin2, '') = ''

update RecoveryAccountProviders
set PhysicalAddressLine1Address = MailingAddressLine1Address,
PhysicalAddressLine2Address = MailingAddressLine2Address,
PhysicalAddressCityName = MailingAddressCityName,
PhysicalAddressStateCode = MailingAddressStateCode,
PhysicalAddressZipCode = MailingAddressZipCode
            
go

grant execute on FillRecoveryAccountProviders to public
go

